==> opensearch-dashboards-2.6.0-1-aarch64.pkg.tar.xz: usr/share/opensearch-dashboards/src/plugins/opensearch_dashboards_overview/common/index.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PLUGIN_PATH = exports.PLUGIN_NAME = exports.PLUGIN_ID = exports.PLUGIN_ICON = void 0;

/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
const PLUGIN_ID = 'opensearchDashboardsOverview';
exports.PLUGIN_ID = PLUGIN_ID;
const PLUGIN_NAME = 'Overview';
exports.PLUGIN_NAME = PLUGIN_NAME;
const PLUGIN_PATH = `/app/opensearch_dashboards_overview`;
exports.PLUGIN_PATH = PLUGIN_PATH;
const PLUGIN_ICON = 'inputOutput';
exports.PLUGIN_ICON = PLUGIN_ICON;

==> opensearch-dashboards-2.18.0-1-aarch64.pkg.tar.xz: usr/share/opensearch-dashboards/src/plugins/opensearch_dashboards_overview/common/index.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PLUGIN_PATH = exports.PLUGIN_NAME = exports.PLUGIN_ID = exports.PLUGIN_ICON = void 0;
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

const PLUGIN_ID = exports.PLUGIN_ID = 'opensearchDashboardsOverview';
const PLUGIN_NAME = exports.PLUGIN_NAME = 'Overview';
const PLUGIN_PATH = exports.PLUGIN_PATH = `/app/opensearch_dashboards_overview`;
const PLUGIN_ICON = exports.PLUGIN_ICON = 'inputOutput';
